@@ -700,6 +700,8 @@ class ListDisplayAdmin(ExcelImportExportAdmin):
 
     origin_list = False     # 展示原str
 
+    add_first_field_to_link = False
+
     def __init__(self, *args, **kwargs):
         """
         增加一个可点击字段
@@ -714,7 +716,7 @@ class ListDisplayAdmin(ExcelImportExportAdmin):
             self.origin_list = True
             return
 
-        if not self.list_display_links and len(field_names) >= 2:
+        if self.add_first_field_to_link and self.list_display_links is not None and (not self.list_display_links) and len(field_names) >= 2:
             if field_names[0] == 'id':
                 self.list_display_links = ('id', field_names[1])
 
