@@ -50,7 +50,7 @@ def get_list(query_dc, key):
     if isinstance(query_dc, QueryDict):
         ret = query_dc.getlist(key)
     elif isinstance(query_dc, dict):
-        ret = query_dc.get(key)
+        ret = query_dc.get(key, [])
     else:
         raise TypeError('query_dc类型不明!')
 
@@ -72,15 +72,21 @@ def get_key_from_request_data_or_self_obj(request_data, self_obj, key, get_type=
     query_dc = request_data
 
     # 让request携带的数据可以覆盖自身的key值
-    ret_0 = getattr(self_obj, key) if hasattr(self_obj, key) else None
+    if isinstance(self_obj, dict):
+        ret_0 = self_obj.get(key)
+    else:
+        ret_0 = getattr(self_obj, key) if hasattr(self_obj, key) else None
 
     if get_type == 'list':
         value = get_list(query_dc, key)
-        ret = value if value not in [None, [], ['']] else ret_0
+        if '__None__' in value:
+            ret = []
+        else:
+            ret = value if value not in [None, [], [''], ""] else ret_0
         return ret
     elif get_type == 'bool':
         value = query_dc.get(key)
-        ret_0 = getattr(self_obj, key) if hasattr(self_obj, key) else None
+        # ret_0 = getattr(self_obj, key) if hasattr(self_obj, key) else None
         ret_1 = pure.convert_query_parameter_to_bool(value) if value else None
         ret = ret_1 if ret_1 is not None else ret_0
         return bool(ret)
