@@ -143,7 +143,9 @@ def convert_query_parameter_to_bool(query_parameter, false_ls=None):
     :return: bool, true or false
     """
     if false_ls is None:
-        false_ls = ['0', 0, None, 'None', 'Null', [], [''], {}, 'False', 'false', '', 'null']
+        false_ls = [
+            '0', 0, None, 'None', 'Null', [], [''], {}, 'False', 'false', '', 'null', 'F', 'f', '__None__', ['__None__']
+        ]
     ret = query_parameter not in false_ls
     return ret
 
